@@ -7,7 +7,6 @@ from .types import (
     Account,
     Collection,
     Comment,
-    ReplyMessage,
     DirectMedia,
     DirectMessage,
     DirectResponse,
@@ -18,6 +17,8 @@ from .types import (
     Location,
     Media,
     MediaOembed,
+    NoteRequest,
+    ReplyMessage,
     Resource,
     Story,
     StoryLink,
@@ -65,9 +66,7 @@ def extract_media_v1(data):
     )
     media["like_count"] = media.get("like_count", 0)
     media["has_liked"] = media.get("has_liked", False)
-    media["sponsor_tags"] = [
-        tag["sponsor"] for tag in media.get("sponsor_tags", [])
-    ]
+    media["sponsor_tags"] = [tag["sponsor"] for tag in media.get("sponsor_tags", [])]
     media["play_count"] = media.get("play_count", 0)
     return Media(
         caption_text=(media.get("caption") or {}).get("text", ""),
@@ -135,7 +134,7 @@ def extract_media_gql(data):
             for edge in media.get("edge_sidecar_to_children", {}).get("edges", [])
         ],
         sponsor_tags=[
-            extract_user_short(edge['node']['sponsor'])
+            extract_user_short(edge["node"]["sponsor"])
             for edge in media.get("edge_media_to_sponsor_user", {}).get("edges", [])
         ],
         **media,
@@ -249,9 +248,7 @@ def extract_direct_thread(data):
     data["messages"] = []
     for item in data["items"]:
         item["thread_id"] = data["id"]
-        data["messages"].append(
-            extract_direct_message(item)
-        )
+        data["messages"].append(extract_direct_message(item))
     data["users"] = [extract_user_short(u) for u in data["users"]]
     if "inviter" in data:
         data["inviter"] = extract_user_short(data["inviter"])
@@ -298,6 +295,9 @@ def extract_direct_message(data):
         data["media_share"] = extract_media_v1(ms)
     if "media" in data:
         data["media"] = extract_direct_media(data["media"])
+    if "voice_media" in data:
+        if "media" in data["voice_media"]:
+            data["media"] = extract_direct_media(data["voice_media"]["media"])
     clip = data.get("clip", {})
     if clip:
         if "clip" in clip:
@@ -321,6 +321,8 @@ def extract_direct_media(data):
         )[-1]["url"]
     if "user" in media:
         media["user"] = extract_user_short(media.get("user"))
+    if "audio" in media:
+        media["audio_url"] = media["audio"].get("audio_src")
     return DirectMedia(**media)
 
 
@@ -361,9 +363,9 @@ def extract_story_v1(data):
     ]
     story["locations"] = []
     story["hashtags"] = []
-    story["stickers"] = data.get('story_link_stickers') or []
+    story["stickers"] = data.get("story_link_stickers") or []
     feed_medias = []
-    story_feed_medias = data.get('story_feed_media') or []
+    story_feed_medias = data.get("story_feed_media") or []
     for feed_media in story_feed_medias:
         feed_media["media_pk"] = int(feed_media["media_id"])
         feed_medias.append(StoryMedia(**feed_media))
@@ -373,9 +375,7 @@ def extract_story_v1(data):
         for link in cta.get("links", []):
             story["links"].append(StoryLink(**link))
     story["user"] = extract_user_short(story.get("user"))
-    story["sponsor_tags"] = [
-        tag["sponsor"] for tag in story.get("sponsor_tags", [])
-    ]
+    story["sponsor_tags"] = [tag["sponsor"] for tag in story.get("sponsor_tags", [])]
     return Story(**story)
 
 
@@ -385,7 +385,8 @@ def extract_story_gql(data):
     if "video_resources" in story:
         # Select Best Quality by Resolutiuon
         story["video_url"] = sorted(
-            story["video_resources"], key=lambda o: o["config_height"] * o["config_width"]
+            story["video_resources"],
+            key=lambda o: o["config_height"] * o["config_width"],
         )[-1]["src"]
     story["product_type"] = "story"
     story["thumbnail_url"] = story.get("display_url")
@@ -408,7 +409,7 @@ def extract_story_gql(data):
     story["links"] = []
     story_cta_url = story.get("story_cta_url", [])
     if story_cta_url:
-        story["links"] = [StoryLink(**{'webUri': story_cta_url})]
+        story["links"] = [StoryLink(**{"webUri": story_cta_url})]
     story["user"] = extract_user_short(story.get("owner"))
     story["pk"] = int(story["id"])
     story["id"] = f"{story['id']}_{story['owner']['id']}"
@@ -416,7 +417,7 @@ def extract_story_gql(data):
     story["taken_at"] = story["taken_at_timestamp"]
     story["media_type"] = 2 if story["is_video"] else 1
     story["sponsor_tags"] = [
-        extract_user_short(edge['node']['sponsor'])
+        extract_user_short(edge["node"]["sponsor"])
         for edge in story.get("edge_media_to_sponsor_user", {}).get("edges", [])
     ]
     return Story(**story)
@@ -424,17 +425,22 @@ def extract_story_gql(data):
 
 def extract_highlight_v1(data):
     highlight = deepcopy(data)
-    highlight['pk'] = highlight['id'].split(':')[1]
-    highlight['items'] = [
-        extract_story_v1(item)
-        for item in highlight.get('items', [])
-    ]
+    highlight["pk"] = highlight["id"].split(":")[1]
+    highlight["items"] = [extract_story_v1(item) for item in highlight.get("items", [])]
     return Highlight(**highlight)
 
 
 def extract_track(data):
-    data['cover_artwork_uri'] = data.get('cover_artwork_uri') or None
-    data['cover_artwork_thumbnail_uri'] = data.get('cover_artwork_thumbnail_uri') or None
-    items = re.findall(r"<BaseURL>(.+?)</BaseURL>", data['dash_manifest'])
-    data['uri'] = html.unescape(items[0]) if items else None
+    data["cover_artwork_uri"] = data.get("cover_artwork_uri") or None
+    data["cover_artwork_thumbnail_uri"] = (
+        data.get("cover_artwork_thumbnail_uri") or None
+    )
+    items = re.findall(r"<BaseURL>(.+?)</BaseURL>", data["dash_manifest"])
+    data["uri"] = html.unescape(items[0]) if items else None
     return Track(**data)
+
+
+def extract_note(data):
+    data["text"] = data.get("text") or None
+    data["uuid"] = data.get("uuid") or None
+    return NoteRequest(**data)
