@@ -25,6 +25,7 @@ SELECTED_FILTERS = ("flagged", "unread")
 
 try:
     from typing import Literal
+
     SELECTED_FILTER = Literal[SELECTED_FILTERS]
 except ImportError:
     # python <= 3.8
@@ -36,8 +37,12 @@ class DirectMixin:
     Helpers for managing Direct Messaging
     """
 
-    def direct_threads(self, amount: int = 20, selected_filter: SELECTED_FILTER = "",
-                       thread_message_limit: Optional[int] = None) -> List[DirectThread]:
+    def direct_threads(
+        self,
+        amount: int = 20,
+        selected_filter: SELECTED_FILTER = "",
+        thread_message_limit: Optional[int] = None,
+    ) -> List[DirectThread]:
         """
         Get direct message threads
 
@@ -59,16 +64,17 @@ class DirectMixin:
             "limit": "20",
         }
         if selected_filter:
-            assert selected_filter in SELECTED_FILTERS, \
-                f'Unsupported selected_filter="{selected_filter}" {SELECTED_FILTERS}'
-            params.update({
-                "selected_filter": selected_filter,
-                "fetch_reason": "manual_refresh",
-            })
+            assert (
+                selected_filter in SELECTED_FILTERS
+            ), f'Unsupported selected_filter="{selected_filter}" {SELECTED_FILTERS}'
+            params.update(
+                {
+                    "selected_filter": selected_filter,
+                    "fetch_reason": "manual_refresh",
+                }
+            )
         if thread_message_limit:
-            params.update({
-                "thread_message_limit": thread_message_limit
-            })
+            params.update({"thread_message_limit": thread_message_limit})
         cursor = None
         threads = []
         # self.private_request("direct_v2/get_presence/")
@@ -208,7 +214,9 @@ class DirectMixin:
         assert self.user_id, "Login required"
         return self.direct_send(text, [], [int(thread_id)])
 
-    def direct_send(self, text: str, user_ids: List[int] = [], thread_ids: List[int] = []) -> DirectMessage:
+    def direct_send(
+        self, text: str, user_ids: List[int] = [], thread_ids: List[int] = []
+    ) -> DirectMessage:
         """
         Send a direct message to list of users or threads
 
@@ -229,7 +237,9 @@ class DirectMixin:
             An object of DirectMessage
         """
         assert self.user_id, "Login required"
-        assert (user_ids or thread_ids) and not (user_ids and thread_ids), "Specify user_ids or thread_ids, but not both"
+        assert (user_ids or thread_ids) and not (
+            user_ids and thread_ids
+        ), "Specify user_ids or thread_ids, but not both"
         method = "text"
         token = self.generate_mutation_token()
         kwargs = {
@@ -254,11 +264,13 @@ class DirectMixin:
         result = self.private_request(
             f"direct_v2/threads/broadcast/{method}/",
             data=self.with_default_data(kwargs),
-            with_signature=False
+            with_signature=False,
         )
         return extract_direct_message(result["payload"])
 
-    def direct_send_photo(self, path: Path, user_ids: List[int] = [], thread_ids: List[int] = []) -> DirectMessage:
+    def direct_send_photo(
+        self, path: Path, user_ids: List[int] = [], thread_ids: List[int] = []
+    ) -> DirectMessage:
         """
         Send a direct photo to list of users or threads
 
@@ -276,9 +288,11 @@ class DirectMixin:
         DirectMessage
             An object of DirectMessage
         """
-        return self.direct_send_file(path, user_ids, thread_ids, content_type='photo')
+        return self.direct_send_file(path, user_ids, thread_ids, content_type="photo")
 
-    def direct_send_video(self, path: Path, user_ids: List[int] = [], thread_ids: List[int] = []) -> DirectMessage:
+    def direct_send_video(
+        self, path: Path, user_ids: List[int] = [], thread_ids: List[int] = []
+    ) -> DirectMessage:
         """
         Send a direct video to list of users or threads
 
@@ -296,9 +310,15 @@ class DirectMixin:
         DirectMessage
             An object of DirectMessage
         """
-        return self.direct_send_file(path, user_ids, thread_ids, content_type='video')
+        return self.direct_send_file(path, user_ids, thread_ids, content_type="video")
 
-    def direct_send_file(self, path: Path, user_ids: List[int] = [], thread_ids: List[int] = [], content_type: str = 'photo') -> DirectMessage:
+    def direct_send_file(
+        self,
+        path: Path,
+        user_ids: List[int] = [],
+        thread_ids: List[int] = [],
+        content_type: str = "photo",
+    ) -> DirectMessage:
         """
         Send a direct file to list of users or threads
 
@@ -317,7 +337,9 @@ class DirectMixin:
             An object of DirectMessage
         """
         assert self.user_id, "Login required"
-        assert (user_ids or thread_ids) and not (user_ids and thread_ids), "Specify user_ids or thread_ids, but not both"
+        assert (user_ids or thread_ids) and not (
+            user_ids and thread_ids
+        ), "Specify user_ids or thread_ids, but not both"
         method = f"configure_{content_type}"
         token = self.generate_mutation_token()
         nav_chains = [
@@ -346,8 +368,10 @@ class DirectMixin:
             data["thread_ids"] = dumps([int(tid) for tid in thread_ids])
         path = Path(path)
         upload_id = str(int(time.time() * 1000))
-        upload_id, width, height = getattr(self, f'{content_type}_rupload')(path, upload_id, **kwargs)[:3]
-        data['upload_id'] = upload_id
+        upload_id, width, height = getattr(self, f"{content_type}_rupload")(
+            path, upload_id, **kwargs
+        )[:3]
+        data["upload_id"] = upload_id
         # data['content_type'] = content_type
         result = self.private_request(
             f"direct_v2/threads/broadcast/{method}/",
@@ -395,12 +419,12 @@ class DirectMixin:
         """
         result = self.private_request(
             "direct_v2/ranked_recipients/",
-            params={"mode": "raven", "show_threads": "true", "query": str(query)}
+            params={"mode": "raven", "show_threads": "true", "query": str(query)},
         )
         return [
-            extract_direct_short_thread(item.get('thread', {}))
-            for item in result.get('ranked_recipients', [])
-            if 'thread' in item
+            extract_direct_short_thread(item.get("thread", {}))
+            for item in result.get("ranked_recipients", [])
+            if "thread" in item
         ]
 
     def direct_thread_by_participants(self, user_ids: List[int]) -> DirectThread:
@@ -420,15 +444,15 @@ class DirectMixin:
         recipient_users = dumps([int(uid) for uid in user_ids])
         result = self.private_request(
             "direct_v2/threads/get_by_participants/",
-            params={"recipient_users": recipient_users, "seq_id": 2580572, "limit": 20}
+            params={"recipient_users": recipient_users, "seq_id": 2580572, "limit": 20},
         )
-        if 'thread' not in result:
+        if "thread" not in result:
             raise DirectThreadNotFound(
-                f'Thread not found by recipient_users={recipient_users}',
+                f"Thread not found by recipient_users={recipient_users}",
                 user_ids=user_ids,
-                **self.last_json
+                **self.last_json,
             )
-        return extract_direct_thread(result['thread'])
+        return extract_direct_thread(result["thread"])
 
     def direct_thread_hide(self, thread_id: int) -> bool:
         """
@@ -446,12 +470,9 @@ class DirectMixin:
             A boolean value
         """
         data = self.with_default_data({})
-        data.pop('_uid', None)
-        data.pop('device_id', None)
-        result = self.private_request(
-            f"direct_v2/threads/{thread_id}/hide/",
-            data=data
-        )
+        data.pop("_uid", None)
+        data.pop("device_id", None)
+        result = self.private_request(f"direct_v2/threads/{thread_id}/hide/", data=data)
         return result["status"] == "ok"
 
     def direct_media_share(self, media_id: str, user_ids: List[int]) -> DirectMessage:
@@ -475,15 +496,15 @@ class DirectMixin:
         media_id = self.media_id(media_id)
         recipient_users = dumps([[int(uid) for uid in user_ids]])
         data = {
-            'recipient_users': recipient_users,
-            'action': 'send_item',
-            'is_shh_mode': 0,
-            'send_attribution': 'feed_timeline',
-            'client_context': token,
-            'media_id': media_id,
-            'mutation_token': token,
-            'nav_chain': '1VL:feed_timeline:1,1VL:feed_timeline:2,1VL:feed_timeline:5,DirectShareSheetFragment:direct_reshare_sheet:6',
-            'offline_threading_id': token,
+            "recipient_users": recipient_users,
+            "action": "send_item",
+            "is_shh_mode": 0,
+            "send_attribution": "feed_timeline",
+            "client_context": token,
+            "media_id": media_id,
+            "mutation_token": token,
+            "nav_chain": "1VL:feed_timeline:1,1VL:feed_timeline:2,1VL:feed_timeline:5,DirectShareSheetFragment:direct_reshare_sheet:6",
+            "offline_threading_id": token,
         }
         result = self.private_request(
             "direct_v2/threads/broadcast/media_share/",
@@ -493,7 +514,9 @@ class DirectMixin:
         )
         return extract_direct_message(result["payload"])
 
-    def direct_story_share(self, story_id: str, user_ids: List[int] = [], thread_ids: List[int] = []) -> DirectMessage:
+    def direct_story_share(
+        self, story_id: str, user_ids: List[int] = [], thread_ids: List[int] = []
+    ) -> DirectMessage:
         """
         Share a story to list of users
 
@@ -512,7 +535,9 @@ class DirectMixin:
             An object of DirectMessage
         """
         assert self.user_id, "Login required"
-        assert (user_ids or thread_ids) and not (user_ids and thread_ids), "Specify user_ids or thread_ids, but not both"
+        assert (user_ids or thread_ids) and not (
+            user_ids and thread_ids
+        ), "Specify user_ids or thread_ids, but not both"
         story_id = self.media_id(story_id)
         story_pk = self.media_pk(story_id)
         token = self.generate_mutation_token()
@@ -555,11 +580,10 @@ class DirectMixin:
             A boolean value
         """
         data = self.with_default_data({})
-        data.pop('_uid', None)
-        data.pop('device_id', None)
+        data.pop("_uid", None)
+        data.pop("device_id", None)
         result = self.private_request(
-            f"direct_v2/threads/{thread_id}/mark_unread/",
-            data=data
+            f"direct_v2/threads/{thread_id}/mark_unread/", data=data
         )
         return result["status"] == "ok"
 
@@ -580,14 +604,13 @@ class DirectMixin:
             A boolean value
         """
         data = self.with_default_data({})
-        data.pop('_uid', None)
-        data.pop('device_id', None)
-        data['is_shh_mode'] = 0
-        data['send_attribution'] = 'direct_thread'
-        data['original_message_client_context'] = self.generate_mutation_token()
+        data.pop("_uid", None)
+        data.pop("device_id", None)
+        data["is_shh_mode"] = 0
+        data["send_attribution"] = "direct_thread"
+        data["original_message_client_context"] = self.generate_mutation_token()
         result = self.private_request(
-            f"direct_v2/threads/{thread_id}/items/{message_id}/delete/",
-            data=data
+            f"direct_v2/threads/{thread_id}/items/{message_id}/delete/", data=data
         )
         return result["status"] == "ok"
 
@@ -609,8 +632,7 @@ class DirectMixin:
         """
         name = "unmute" if revert else "mute"
         result = self.private_request(
-            f"direct_v2/threads/{thread_id}/{name}/",
-            data={'_uuid': self.uuid}
+            f"direct_v2/threads/{thread_id}/{name}/", data={"_uuid": self.uuid}
         )
         return result["status"] == "ok"
 
@@ -630,7 +652,9 @@ class DirectMixin:
         """
         return self.direct_thread_mute(thread_id, revert=True)
 
-    def direct_thread_mute_video_call(self, thread_id: int, revert: bool = False) -> bool:
+    def direct_thread_mute_video_call(
+        self, thread_id: int, revert: bool = False
+    ) -> bool:
         """
         Mute video call for the thread
 
@@ -648,8 +672,7 @@ class DirectMixin:
         """
         name = "unmute_video_call" if revert else "mute_video_call"
         result = self.private_request(
-            f"direct_v2/threads/{thread_id}/{name}/",
-            data={'_uuid': self.uuid}
+            f"direct_v2/threads/{thread_id}/{name}/", data={"_uuid": self.uuid}
         )
         return result["status"] == "ok"
 
@@ -669,7 +692,9 @@ class DirectMixin:
         """
         return self.direct_thread_mute_video_call(thread_id, revert=True)
 
-    def direct_profile_share(self, user_id: str, user_ids: List[int] = [], thread_ids: List[int] = []) -> DirectMessage:
+    def direct_profile_share(
+        self, user_id: str, user_ids: List[int] = [], thread_ids: List[int] = []
+    ) -> DirectMessage:
         """
         Share a profile to list of users
 
@@ -688,7 +713,9 @@ class DirectMixin:
             An object of DirectMessage
         """
         assert self.user_id, "Login required"
-        assert (user_ids or thread_ids) and not (user_ids and thread_ids), "Specify user_ids or thread_ids, but not both"
+        assert (user_ids or thread_ids) and not (
+            user_ids and thread_ids
+        ), "Specify user_ids or thread_ids, but not both"
         token = self.generate_mutation_token()
         data = {
             "action": "send_item",
@@ -729,10 +756,7 @@ class DirectMixin:
             A list of objects of Media
         """
         assert self.user_id, "Login required"
-        params = {
-            "limit": 20,
-            "media_type": "photos_and_videos"
-        }
+        params = {"limit": 20, "media_type": "photos_and_videos"}
         max_timestamp = None
         items = []
         while True:
